@@ -159,22 +159,25 @@ class ClassList(object):
             closeFile = False
         name = self._name
         title = 'Class %s of %s' % (
-            hierarchic and 'Hierarchy' or 'List', name)
-        other = ('<a href="Class%s.html">%s class list<a>'
-            ' and the <a href="FileList.html">list of files<a> of %s'
-            % (hierarchic and 'List' or 'Hierarchy',
-                hierarchic and 'alphabetical' or 'hierarchical', name))
-        file.write('''<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
+            'Hierarchy' if hierarchic else 'List', name)
+        other = ('<a href="Class%s.html">%s class list</a>'
+            ' and the <a href="FileList.html">list of files</a> of %s'
+            % ('List' if hierarchic else 'Hierarchy',
+                'alphabetical' if hierarchic else 'hierarchical', name))
+        file.write('''<!DOCTYPE html>
 <head>
 <title>%s</title>
 <style type="text/css">
 <!--
 body { background: #FFF;
-font-family: Verdana, Arial, Helvetica, sans-serif;
-font-size: 10pt;
+font-family: Verdana, Arial, Helvetica, sans-serif; font-size: 10pt;
 padding: 6pt; }
-th { background-color: #CCF; text-align: left; }
-td { background-color: #EEF; }
+table { empty-cells: show;
+border-spacing: 2px; border-collapse: separate; border-style: none; }
+th { background-color: #CCF; text-align: left;
+padding: 2px; border-style: none; }
+td { background-color: #EEF;
+padding: 2px; border-style: none; }
 .center { text-align: center; }
 .center table { margin-left: auto; margin-right: auto; text-align: left; }
 -->
@@ -183,7 +186,7 @@ td { background-color: #EEF; }
 <body><div class="center">
 <h1>%s</h1>
 <p>See also the %s.</p>
-<table cellpadding="2" cellspacing="2">
+<table>
 ''' % (title, title, other))
         file.write('<tr><th>Class Name</th><th>Source File</th>'
             '<th>Source</th><th>Doc</th><th>Summary</th></tr>\n')
@@ -210,7 +213,7 @@ td { background-color: #EEF; }
         name = self._name
         filename = klass.filename()
         links = []
-        # souce file
+        # source file
         if os.path.exists(filename):
             links.append('<a href="../../%s">%s</a>' % (filename, filename))
         else:
