@@ -60,10 +60,10 @@ class FileList(object):
             closeFile = False
         name = self._name
         title = 'File List of %s' % name
-        other = ('<a href="ClassList.html">alphabetical class list<a>'
+        other = ('<a href="ClassList.html">alphabetical class list</a>'
             ' and <a href="ClassHierarchy.html">class hierarchy</a>'
             ' of %s' % name)
-        file.write('''<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
+        file.write('''<!DOCTYPE html>
 <head>
 <title>%s</title>
 <style type="text/css">
@@ -72,8 +72,12 @@ body { background: #FFF;
 font-family: Verdana, Arial, Helvetica, sans-serif;
 font-size: 10pt;
 padding: 6pt; }
-th { background-color: #CCF; text-align: left; }
-td { background-color: #EEF; }
+table { empty-cells: show;
+border-spacing: 2px; border-collapse: separate; border-style: none; }
+th { background-color: #CCF; text-align: left;
+padding: 2px; border-style: none; }
+td { background-color: #EEF;
+padding: 2px; border-style: none; }
 .center { text-align: center; }
 .center table { margin-left: auto; margin-right: auto; text-align: left; }
 -->
@@ -82,7 +86,7 @@ td { background-color: #EEF; }
 <body><div class="center">
 <h1>%s</h1>
 <p>See also the %s.</p>
-<table cellpadding="2" cellspacing="2">
+<table>
 ''' % (title, title, other))
         file.write('<tr><th>Source File</th>'
             '<th>Source</th><th>Doc</th><th>Summary</th></tr>\n')
@@ -98,7 +102,7 @@ td { background-color: #EEF; }
         """In support of printForWeb()"""
         name = self._name
         links = []
-        # souce file
+        # source file
         if os.path.exists(filename):
             links.append('<a href="../../%s">%s</a>' % (filename, filename))
         else:
