@@ -793,7 +793,7 @@ class MiddleObjectMixIn(object):
         for attr in sqlAttrs:
             try:
                 value = attr.sqlValue(self.valueForAttr(attr))
-            except UnknownSerialNumberError, exc:
+            except UnknownSerialNumberError as exc:
                 exc.info.sourceObject = self
                 unknowns.append(exc.info)
                 if self.store().model().setting('UseBigIntObjRefColumns', False):
@@ -990,13 +990,13 @@ class LongAttr(object):
 class DecimalAttr(object):
 
     def sqlForNonNone(self, value):
-        return str(value)  # repr() can give Decimal("3.4") in Python 2.4
+        return str(value)  # repr() will give Decimal("3.4")
 
 
 class BoolAttr(object):
 
     def sqlForNonNone(self, value):
-        return value and '1' or '0'  # MySQL and MS SQL will take 1 and 0 for bools
+        return '1' if value else '0'  # MySQL and MS SQL will take 1 and 0 for bools
 
 
 class ObjRefAttr(object):
