@@ -85,7 +85,7 @@ class PropertiesObject(dict):
         The micro version number is only excluded from the string if it is zero.
         """
         ver = map(str, version)
-        numbers, rest = ver[:ver[2] == '0' and 2 or 3], ver[3:]
+        numbers, rest = ver[:2 if ver[2] == '0' else 3], ver[3:]
         return '.'.join(numbers) + '-'.join(rest)
 
     def createVersionString(self):
@@ -102,7 +102,7 @@ class PropertiesObject(dict):
                 methodName = 'check' + key[0].upper() + key[1:]
                 method = getattr(self, methodName)
                 method()
-        except WillNotRunError, msg:
+        except WillNotRunError as msg:
             self['willNotRunReason'] = msg
             return
         self['willRun'] = 1  # we passed all the tests
