@@ -233,7 +233,8 @@ class Application(ConfigurableForServerSidePath):
                 " from module '%s'") % (className, moduleName)
             self._sessionClass = None
         moduleName = self.setting('SessionStore')
-        if moduleName in ('Dynamic', 'File', 'Memcached', 'Memory', 'Shelve'):
+        if moduleName in (
+                'Dynamic', 'File', 'Memcached', 'Memory', 'Redis', 'Shelve'):
             moduleName = 'Session%sStore' % moduleName
         self._sessionDir = self.serverSidePath(
             self.setting('SessionStoreDir') or 'Sessions')
@@ -244,7 +245,7 @@ class Application(ConfigurableForServerSidePath):
             if not isinstance(cls, type):
                 raise ImportError
             self._sessions = cls(self)
-        except ImportError, err:
+        except ImportError as err:
             print ("ERROR: Could not import SessionStore class '%s'"
                 " from module '%s':\n%s") % (className, moduleName, err)
             self._sessions = None
@@ -546,7 +547,7 @@ class Application(ConfigurableForServerSidePath):
                     self.runTransaction(trans)
                     try:
                         trans.response().deliver()
-                    except ConnectionAbortedError, err:
+                    except ConnectionAbortedError as err:
                         trans.setError(err)
                     response.clearTransaction()
                     # release possible servlets on the stack
@@ -610,19 +611,14 @@ class Application(ConfigurableForServerSidePath):
             self.runTransactionViaServlet(servlet, trans)
         except EndResponse:
             pass
-        except ConnectionAbortedError, err:
+        except ConnectionAbortedError as err:
             trans.setError(err)
         except (KeyboardInterrupt, SystemExit):
             raise  # do not catch these here
         except:
             # For once, we use a bare except here in order to catch
-            # string and non standard exceptions from legacy code
-            # (starting with Python 2.5 you can simply catch Exception;
-            # KeyboardInterrupt, SystemExit will be excluded already
-            # and string exceptions will output deprecation warnings).
+            # exceptions from legacy code which are old-style classes.
             errClass, err = sys.exc_info()[:2]
-            if not err:  # string exception
-                err, errClass = errClass, None
             urls = {}
             while 1:
                 trans.setError(err)
@@ -654,7 +650,7 @@ class Application(ConfigurableForServerSidePath):
                     self.forward(trans, url)
                 except EndResponse:
                     pass
-                except ConnectionAbortedError, err:
+                except ConnectionAbortedError as err:
                     trans.setError(err)
                 except (KeyboardInterrupt, SystemExit):
                     raise  # do not catch these here
@@ -664,8 +660,6 @@ class Application(ConfigurableForServerSidePath):
                     # display the new exception instead of the original one,
                     # so we notice that something is broken here.
                     errClass, err = sys.exc_info()[:2]
-                    if not err:  # string exception
-                        err, errClass = errClass, None
                     url = None
                 if url:
                     return  # error has already been handled
@@ -840,8 +834,8 @@ class Application(ConfigurableForServerSidePath):
         `ExceptionHandler.ExceptionHandler`.
         """
         request = trans.request()
-        editlink = (self.setting('IncludeEditLink')
-            and request.adapterName() + "/Admin/EditFile" or None)
+        editlink = (request.adapterName() + '/Admin/EditFile'
+            if self.setting('IncludeEditLink') else None)
         self._exceptionHandlerClass(self, trans, excInfo,
             dict(editlink=editlink))
 
@@ -946,7 +940,7 @@ class Application(ConfigurableForServerSidePath):
         http://gandalf/a/_SID_=2001080221301877755/Examples/
         _SID_ is extracted and removed from path in HTTPRequest.py
 
-        This is for convinient building of webapps that must not
+        This is for convenient building of webapps that must not
         depend on cookie support.
 
         Note that we create an absolute URL with scheme and hostname
@@ -957,7 +951,7 @@ class Application(ConfigurableForServerSidePath):
             request.hostAndPort(), request.servletPath(),
             self.sessionName(trans), trans.session().identifier(),
             request.pathInfo(), request.extraURLPath() or '',
-            request.queryString() and '?' + request.queryString() or '')
+            '?' + request.queryString() if request.queryString() else '')
         if self.setting('Debug')['Sessions']:
             print ('>> [sessions] handling UseAutomaticPathSessions, '
                 'redirecting to', url)
@@ -975,7 +969,7 @@ class Application(ConfigurableForServerSidePath):
         url = '%s://%s%s%s%s%s' % (request.scheme(),
             request.hostAndPort(), request.servletPath(),
             request.pathInfo(), request.extraURLPath() or '',
-            request.queryString() and '?' + request.queryString() or '')
+            '?' + request.queryString() if request.queryString() else '')
         if self.setting('Debug')['Sessions']:
             print ('>> [sessions] handling unnecessary path session, '
                 'redirecting to', url)
