@@ -30,12 +30,12 @@ Tested on:
     - WingIDE on Windows, http://wingware.com/
     - PythonWin
     - JEdit with the JPyDbg plugin, on Windows
-
 """
 
 import sys
 
-import ThreadedAppServer, Profiler
+import ThreadedAppServer
+import Profiler
 
 # We are going to replace ThreadedAppServer with our own class,
 # so we need to save a reference to the original class.
@@ -52,7 +52,6 @@ class DebugAppServer(OriginalThreadedAppServer):
     trick is to replace the request queue with a dummy object that
     executes requests immediately instead of pushing them onto a queue
     to be handled by other threads.
-
     """
 
 
@@ -89,7 +88,6 @@ class DebugAppServer(OriginalThreadedAppServer):
         This is needed for COM support on Windows, because special thread
         initialization is required on any thread that runs servlets, in
         this case the main thread itself.
-
         """
         self.initThread()
         try:
@@ -138,7 +136,6 @@ class DebugApplication(Application):
         This should only be used in cases where there is no transaction object,
         for example if an exception occurs when attempting to save a session
         to disk.
-
         """
         raise
 
@@ -147,7 +144,6 @@ class DebugApplication(Application):
 
         Raises exception `excInfo` (as returned by ``sys.exc_info()``)
         that was generated by `transaction`.
-
         """
         raise
 
@@ -156,7 +152,6 @@ class DummyRequestQueue(object):
     """This is a dummy replacement for the request queue.
 
     It merely executes handlers as soon as they are "pushed".
-
     """
 
 
