@@ -32,11 +32,12 @@ that save the raw requests.
 
 Caveat: HTTP cookies are blown away from the raw requests. Mostly due to
 the fact that they will contain stale session ids.
-
 """
 
 
-import sys, os, socket
+import sys
+import os
+import socket
 from glob import glob
 from marshal import dumps
 from random import randint
@@ -51,11 +52,11 @@ def usage():
     print '%s usage:' % name
     print '  %s numRequests [minParallelRequests [maxParallelRequests [delay [slowconn]]]]' % name
     print 'Examples:'
-    print '  %s 100            # run 100 sequential requests' % name
-    print '  %s 100 5          # run 100 requests, 5 at a time' % name
-    print '  %s 100 5 10       # run 100 requests, 5-10 at a time' % name
-    print '  %s 100 10 10 0.01 # run 100 requests, 10 at a time, with delay between each set' % name
-    print '  %s 5 1 1 0.1 1    # run 5 sequential requests, simulating a very bad connection' % name
+    print '  %s 100             # run 100 sequential requests' % name
+    print '  %s 100 5           # run 100 requests, 5 at a time' % name
+    print '  %s 100 5 10        # run 100 requests, 5-10 at a time' % name
+    print '  %s 100 10 10 0.01  # run 100 requests, 10 at a time, with delay between each set' % name
+    print '  %s 5 1 1 0.1 1     # run 5 sequential requests, simulating a very bad connection' % name
     print
     sys.exit(1)
 
@@ -65,13 +66,12 @@ def request(names, dicts, host, port, count, delay=0, slowconn=0):
 
     This includes sending the request and receiving the response.
     slowconn simulates a slowed connection from the client.
-
     """
     complete = 0
-    filecount = len(names)
-    totalbytes = 0
+    fileCount = len(names)
+    totalBytes = 0
     while complete < count:
-        i = randint(0, filecount-1)
+        i = randint(0, fileCount - 1)
         # taken from CGIAdapter:
         s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         s.connect((host, port))
@@ -79,19 +79,19 @@ def request(names, dicts, host, port, count, delay=0, slowconn=0):
         data = dumps(len(data)) + data
         if slowconn:
             for d in data:
-                s.send(d)
+                s.sendall(d)
             if delay:
                 sleep(delay)
         else:
-            s.send(data)
+            s.sendall(data)
         s.shutdown(1)
         data = []
         while 1:
-            newdata = s.recv(8192)
-            if not newdata:
+            newData = s.recv(8192)
+            if not newData:
                 break
             else:
-                data.append(newdata)
+                data.append(newData)
         data = ''.join(data)
         # process response
         # sys.stdout.write(data)
@@ -103,7 +103,7 @@ def request(names, dicts, host, port, count, delay=0, slowconn=0):
         except Exception:
             status = 'no status'
             code = 0
-        if code not in (200,): # accepted status codes
+        if code not in (200,):  # accepted status codes
             status = dicts[i]['environ']['PATH_INFO'] + ' ' + status
             raise Exception(status)
         if data.rstrip()[-7:].lower() != '</html>':
@@ -111,7 +111,7 @@ def request(names, dicts, host, port, count, delay=0, slowconn=0):
         if delay:
             sleep(delay)
         complete += 1
-        totalbytes += len(data)
+        totalBytes += len(data)
 
 
 def stress(maxRequests,
@@ -135,8 +135,8 @@ def stress(maxRequests,
         eval(open(filename).read()), requestFilenames)
     # kill the HTTP cookies (which typically have an invalid session id)
     # from when the raw requests were captured
-    for dict in requestDicts:
-        environ = dict['environ']
+    for requestDict in requestDicts:
+        environ = requestDict['environ']
         if 'HTTP_COOKIE' in environ:
             del environ['HTTP_COOKIE']
     requestCount = len(requestFilenames)
