@@ -14,7 +14,7 @@ The ThreadedAppServer/AppServer distinction is thus largely historical.
 ThreadedAppServer takes the following command line arguments:
 
 start: start the AppServer (default argument)
-stop: stop the currently running Apperver
+stop: stop the currently running AppServer
 daemon: run as a daemon
 ClassName.SettingName=value: change configuration settings
 
@@ -34,14 +34,7 @@ from marshal import dumps, loads
 from threading import Thread, currentThread
 from time import time, localtime, sleep
 
-try:
-    from ctypes import pythonapi, c_long, py_object
-except ImportError:
-    py_object = c_long = pythonapi = None
-try:
-    PyThreadState_SetAsyncExc = pythonapi.PyThreadState_SetAsyncExc
-except (TypeError, AttributeError):
-    PyThreadState_SetAsyncExc = None
+from ctypes import pythonapi, c_long, py_object
 
 try:
     import fcntl
@@ -128,8 +121,6 @@ class WorkerThread(Thread):
     (Idea taken from: http://sebulba.wikispaces.com/recipe+thread2)
     """
 
-    _canAbort = PyThreadState_SetAsyncExc is not None
-
     def threadID(self):
         """Return the thread's internal id."""
         try:
@@ -147,10 +138,6 @@ class WorkerThread(Thread):
         a value of zero means the thread could not be found,
         any other value indicates that an error has occurred.
         """
-        if not self._canAbort:
-            if debug:
-                print "Error: Aborting threads is not possible"
-            return -1
         if debug:
             print "Aborting worker thread..."
         try:
@@ -168,12 +155,13 @@ class WorkerThread(Thread):
         if debug:
             print "Worker thread id is", threadID
         try:
-            ret = PyThreadState_SetAsyncExc(
+            ret = pythonapi.PyThreadState_SetAsyncExc(
                 c_long(threadID), py_object(exception))
             # If it returns a number greater than one, we're in trouble,
             # and should call it again with exc=NULL to revert the effect
             if ret > 1:
-                PyThreadState_SetAsyncExc(c_long(threadID), py_object())
+                pythonapi.PyThreadState_SetAsyncExc(
+                    c_long(threadID), py_object())
         except Exception:
             ret = -1
         if debug:
@@ -247,10 +235,6 @@ class ThreadedAppServer(AppServer):
             self._requestQueue = Queue.Queue(self._requestQueueSize)
 
             maxRequestTime = self.setting('MaxRequestTime') or None
-            if maxRequestTime and not self._canAbortRequest:
-                print ("Warning: MaxRequestTime setting ineffective"
-                    " (cannot abort requests)")
-                maxRequestTime = None
             self._maxRequestTime = maxRequestTime
             self._checkRequestTime = None
 
@@ -329,9 +313,8 @@ class ThreadedAppServer(AppServer):
                     sys.stdout.flush()
                     raise
         try:
-            f = open(adrFile, 'w')
-            f.write(adrStr)
-            f.close()
+            with open(adrFile, 'w') as f:
+                f.write(adrStr)
         except IOError:
             print "Error: Could not write", adrFile
             sys.stdout.flush()
@@ -394,7 +377,7 @@ class ThreadedAppServer(AppServer):
                 try:
                     input, output, exc = select.select(
                         self._sockets.values(), [], [], timeout)
-                except select.error, e:
+                except select.error as e:
                     if e[0] not in self._ignoreErrnos:
                         raise
                     if debug:
@@ -405,7 +388,7 @@ class ThreadedAppServer(AppServer):
 
                     try:
                         client, addr = sock.accept()
-                    except select.error, e:
+                    except select.error as e:
                         if e[0] not in self._ignoreErrnos:
                             raise
                         if debug:
@@ -561,8 +544,6 @@ class ThreadedAppServer(AppServer):
                 if debug:
                     print "Thread absorbed, real threadCount =", len(self._threadPool)
 
-    _canAbortRequest = WorkerThread._canAbort
-
     def abortRequest(self, requestID, exception=RequestAbortedError):
         """Abort a request by raising an exception in its worker thread.
 
@@ -573,10 +554,6 @@ class ThreadedAppServer(AppServer):
         verbose = self._verbose
         if verbose:
             print "Aborting request", requestID
-        if not self._canAbortRequest:
-            if verbose:
-                print "Error: Cannot abort requests"
-            return -1
         for t, h in self._threadHandler.items():
             try:
                 handlerRequestID = h._requestID
@@ -766,7 +743,7 @@ class ThreadedAppServer(AppServer):
                 break
         else:
             running = False
-        if running and self._canAbortRequest:
+        if running:
             # Abort all remaining threads:
             print "Aborting hanging worker threads..."
             for t in self._threadPool:
@@ -908,7 +885,7 @@ class Handler(object):
         chunks = ''.join(chunks)
         try:
             dictLength = loads(chunks)
-        except (ValueError, EOFError), msg:
+        except (ValueError, EOFError) as msg:
             if chunks[:3] == 'GET':
                 # Common error: client is speaking HTTP.
                 while msg and len(chunks) < 8192:
@@ -916,8 +893,7 @@ class Handler(object):
                     if not block:
                         break
                     chunks += block
-                    if (chunks.endswith('\r\r') or chunks.endswith('\n\n')
-                            or chunks.endswith('\r\n\r\n')):
+                    if chunks.endswith(('\r\r', '\n\n', '\r\n\r\n')):
                         msg = None
             if msg:
                 print "ERROR:", msg
@@ -972,7 +948,7 @@ See the Troubleshooting section of the WebKit Install Guide.\r''')
         self._requestDict = requestDict
         if self._verbose:
             env = requestDict.get('environ')
-            uri = env and requestURI(env) or '-'
+            uri = requestURI(env) if env else '-'
             if not self._silentURIs or not self._silentURIs.search(uri):
                 requestDict['verbose'] = True
                 requestTime = localtime(requestTime)[:6]
@@ -991,7 +967,7 @@ See the Troubleshooting section of the WebKit Install Guide.\r''')
                 duration = round((time() - requestDict['time'])*1000)
                 if not error:
                     env = requestDict.get('environ')
-                    error = env and requestURI(env) or '-'
+                    error = requestURI(env) if env else '-'
                 print '%5d  %14.0f msec  %s\n' % (
                     requestID, duration, error)
 
@@ -1073,7 +1049,7 @@ class TASStreamOut(ASStreamOut):
                 try:
                     sent += self._socket.send(
                         self._buffer[sent:sent+bufferSize])
-                except socket.error, e:
+                except socket.error as e:
                     if debug or e[0] not in self._ignoreErrnos:
                         print "StreamOut Error:", e
                     self._closed = True
@@ -1170,7 +1146,7 @@ class SCGIHandler(AdapterHandler):
             if len(chunk) > 12 or not chunk.isdigit():
                 raise ValueError('Malformed SCGI netstring')
             dictLength = long(chunk)
-        except ValueError, msg:
+        except ValueError as msg:
             if chunk[:3] == 'GET':
                 # Common error: client is speaking HTTP.
                 while msg and len(chunk) < 8192:
@@ -1178,8 +1154,7 @@ class SCGIHandler(AdapterHandler):
                     if not block:
                         break
                     chunk += block
-                    if (chunk.endswith('\r\r') or chunk.endswith('\n\n')
-                            or chunk.endswith('\r\n\r\n')):
+                    if chunk.endswith(('\r\r', '\n\n', '\r\n\r\n')):
                         msg = None
             if msg:
                 print "ERROR:", msg
@@ -1275,7 +1250,7 @@ def run(workDir=None):
                         global exitStatus
                         try:
                             server.mainloop()
-                        except SystemExit, e:
+                        except SystemExit as e:
                             exitStatus = e[0]
                     # Run the server thread
                     server._running = 2
@@ -1299,16 +1274,16 @@ def run(workDir=None):
                 sys.stdout.flush()
                 sys.stderr.flush()
                 runAgain = True
-            except SystemExit, e:
+            except SystemExit as e:
                 print
                 print "Exiting AppServer%s." % (
-                    e[0] == 3 and ' for reload' or '')
+                    ' for reload' if e[0] == 3 else '')
                 exitStatus = e[0]
             except KeyboardInterrupt:
                 print
                 print "Exiting AppServer due to keyboard interrupt."
                 exitStatus = 0
-            except Exception, e:
+            except Exception as e:
                 if isinstance(e, IOError) and e[0] == errno.EINTR:
                     print
                     print "Exiting AppServer due to interrupt signal."
@@ -1357,17 +1332,6 @@ def shutDown(signum, frame):
     else:
         print "No running app server was found."
 
-try:
-    currentFrames = sys._current_frames
-except AttributeError:  # Python < 2.5
-    # Use the threadframe module for dumping thread stack frames:
-    # http://www.majid.info/mylos/stories/2004/06/10/threadframe.html
-    try:
-        import threadframe
-    except ImportError:  # threadframe module not installed
-        currentFrames = None
-    else:
-        currentFrames = threadframe.dict
 
 def threadDump(signum, frame):
     """Signal handler for dumping thread stack frames to stdout."""
@@ -1376,7 +1340,7 @@ def threadDump(signum, frame):
     print
     print "Thread stack frame dump at", asclocaltime()
     sys.stdout.flush()
-    frames = currentFrames()
+    frames = sys._current_frames()
     print
     print "-" * 79
     print
@@ -1409,21 +1373,19 @@ try:
 except AttributeError:
     SIGINT = None
 
-if currentFrames:
+# Signals for creating a thread dump
 
-    # Signals for creating a thread dump
-
-    try:
-        SIGQUIT = signal.SIGQUIT
-        signal.signal(SIGQUIT, threadDump)
-    except AttributeError:
-        SIGQUIT = None
-    try:
-        # this is Ctrl-Break on Windows (not Cygwin)
-        SIGBREAK = signal.SIGBREAK
-        signal.signal(SIGBREAK, threadDump)
-    except AttributeError:
-        SIGBREAK = None
+try:
+    SIGQUIT = signal.SIGQUIT
+    signal.signal(SIGQUIT, threadDump)
+except AttributeError:
+    SIGQUIT = None
+try:
+    # this is Ctrl-Break on Windows (not Cygwin)
+    SIGBREAK = signal.SIGBREAK
+    signal.signal(SIGBREAK, threadDump)
+except AttributeError:
+    SIGBREAK = None
 
 
 # Command line interface
